imodels.tree.optimal_classification_tree API documentation
Description: Still in progress - should optimize globally over all possible splits rather than use greedy 1-by-1 splits

# Module `imodels.tree.optimal_classification_tree`

Still in progress - should optimize globally over all possible splits rather than use greedy 1-by-1 splits

Expand source code

    '''Still in progress - should optimize globally over all possible splits rather than use greedy 1-by-1 splits
    '''

    __all__ = []

## Sub-modules

`imodels.tree.optimal_classification_tree.example`
`imodels.tree.optimal_classification_tree.localsearch`
`imodels.tree.optimal_classification_tree.optree`
`imodels.tree.optimal_classification_tree.tree`